"""Feature tag filters for face/hand crops.

These are used to filter out tags that clearly do not belong to a feature crop.
"""

from __future__ import annotations

FACE_TAG_BLACKLIST = {
    "abs",
    "back",
    "backpack",
    "background",
    "bed",
    "bikini",
    "boots",
    "bra",
    "building",
    "car",
    "city",
    "cloud",
    "coat",
    "dress",
    "feet",
    "feet out of frame",
    "floor",
    "forest",
    "grass",
    "hand",
    "hands",
    "hat",
    "house",
    "indoor",
    "jacket",
    "kitchen",
    "legs",
    "legs up",
    "landscape",
    "mountain",
    "outdoor",
    "pants",
    "park",
    "pool",
    "road",
    "scenery",
    "shirt",
    "shoes",
    "shorts",
    "skirt",
    "sky",
    "street",
    "table",
    "tattoo",
    "tree",
    "upper body",
    "window",
}

HAND_TAG_BLACKLIST = {
    "abs",
    "age",
    "back",
    "bare shoulders",
    "bare shoulders",
    "bathroom",
    "bed",
    "black hair",
    "blonde hair",
    "blue eyes",
    "blurry",
    "blush",
    "bikini",
    "blue eyes",
    "brown hair",
    "blush",
    "cheek",
    "cheekbones",
    "chin",
    "bra",
    "brown eyes",
    "building",
    "coat",
    "collarbone",
    "city",
    "ear",
    "earrings",
    "eyebrows",
    "eye contact",
    "cleavage",
    "eye focus",
    "cloud",
    "dress",
    "eyewear",
    "eyebrows",
    "face paint",
    "eyes",
    "facial hair",
    "fangs",
    "freckles",
    "full body",
    "eyelashes",
    "green hair",
    "eyeshadow",
    "hair bun",
    "hair ornament",
    "hair over one eye",
    "hair pulled back",
    "face",
    "head",
    "head tilt",
    "headband",
    "helmet",
    "hips",
    "hood",
    "facial",
    "jacket",
    "flux chin",
    "knees",
    "kneeling",
    "legs",
    "legs up",
    "long hair",
    "long sleeves",
    "full body",
    "lipstick",
    "lipstick tube",
    "green eyes",
    "looking away",
    "looking back",
    "looking down",
    "looking to the side",
    "looking up",
    "makeup",
    "mask",
    "messy hair",
    "mouth",
    "open mouth",
    "hair",
    "neck",
    "necklace",
    "nipples",
    "navel",
    "one eye closed",
    "hat",
    "pants",
    "indoors",
    "pantyhose",
    "ponytail",
    "portrait",
    "kitchen",
    "red hair",
    "red lips",
    "red shirt",
    "red dress",
    "ribbon",
    "lips",
    "short hair",
    "short sleeves",
    "looking at the camera",
    "shorts",
    "skirt",
    "smile",
    "nose",
    "socks",
    "standing",
    "stomach",
    "sweater",
    "sweater dress",
    "swimsuit",
    "outdoors",
    "panties",
    "pussy",
    "thighs",
    "thigh-high socks",
    "t-shirt",
    "tongue",
    "shirt",
    "waist",
    "white hair",
    "window",
    "yellow hair",
    "shoes",
    "sky",
    "street",
    "table",
    "teeth",
    "tongue",
    "upper body",
}
